import { ErrorCode } from '@rongcloud/engine';
import { connect } from '../services/index'

const stringifyConf = (conf) => [conf.appkey, conf.token].join('_')
const addToArray = (item, target) => {
    const key = stringifyConf(item)
    const one = target.find(i => stringifyConf(i) === key)
    if (!one) {
        target.push(item)
    } else {
        // 避免 config.js 内配置出错，以登录成功返回的 userId 为准
        one.userId = item.userId
    }
}

// 预录入登录信息
const preloadConf = require('../../config').default;
const history = [...preloadConf]

const STORAGE_KEY = 'login_caches'
// 读取 storage 存储以获取登录缓存历史，合并为 history
const caches = wx.getStorageSync(STORAGE_KEY) || []
caches.forEach(item => addToArray(item, history))

const defaultIndex = 0
const defaultValue = history[defaultIndex] || {}

Page({
  data: {
    history,
    index: 0,
    selected: defaultValue,
    form: {
        appkey: defaultValue.appkey,
        token: defaultValue.token,
        navi: defaultValue.navi,
        mediaServer: defaultValue.mediaServer,
        customCMP: defaultValue.customCMP
    },
  },
  bindPickerChange (e) {
    const index = e.detail.value;
    const selected = history[index]
    this.setData({
      index,
      selected,
      form: { ...selected }
    })
  },
  _changeFormData(key, value) {
    this.setData({
        form: {...this.data.form, [key]: value }
    })
  },
  appkeyChange(e) {
    this._changeFormData('appkey', e.detail.value)
  },
  tokenChange(e) {
    this._changeFormData('token', e.detail.value)
  },
  customCMPChange(e) {
    this._changeFormData('customCMP', e.detail.value)
  },
  naviChange(e) {
    this._changeFormData('navi', e.detail.value)
  },
  mediaServerChange(e) {
    this._changeFormData('mediaServer', e.detail.value)
  },
  async login () {
    const { data: { form } } = this;
    if (!form.token || !form.appkey) {
        wx.showToast({
          title: 'appkey 或 token 无效',
          icon: 'none'
        })
        return;
    }

    wx.showLoading({
        title: '连接中...'
    })

    const { appkey, navi, token, mediaServer, customCMP } = form
    const { code, data } = await connect(appkey, token, navi, mediaServer, customCMP)

    wx.hideLoading()

    if (code !== ErrorCode.SUCCESS) {
        wx.showToast({ title: `登录失败 -> ${code}`, icon: 'none' })
        return
    }

    const userId = data.userId

    // 记录登录历史
    const item = { ...form, userId }
    addToArray(item, caches)
    addToArray(item, history)

    // 存储记录
    wx.setStorageSync(STORAGE_KEY, caches)

    // 导航跳转
    wx.navigateTo({
      url: `../main/main?userId=${userId}`,
    })
  }
})