const {
    init: initIM, destroy, installPlugin, addEventListener, Events,
    connect: connectIM
} = require('@rongcloud/imlib-next');
const { installer, RCRTCClient } = require('@rongcloud/plugin-wechat-rtc');

/**
 * RCRTCClient 实例
 * @type {RCRTCClient}
 */
let rtcClient

export const connect = async (appkey, token, navi, mediaServer, customCMP) => {
    // 避免重复初始化
    await destroy()

    // 初始化 IM
    initIM({
        // logOutputLevel: 3,
        appkey,
        customCMP: customCMP ? [customCMP] : undefined,
        navigators: navi ? [navi] : undefined
    })

    // 监听 IM 事件
    addEventListener(Events.CONNECTED, () => console.log('连接成功'))
    addEventListener(Events.CONNECTING, () => console.log('连接中...'))
    addEventListener(Events.SUSPEND, (code) => console.warn(`连接中断（${code}），恢复中...`))
    addEventListener(Events.DISCONNECT, (code) => console.warn(`连接终止 -> ${code}`))
    addEventListener(Events.MESSAGES, (evt) => console.log(`接收到消息: ${evt.messages.map(item => item.messageUId).join(', ')}`))

    // 初始化 RTC
    rtcClient = installPlugin(installer, {
        mediaServer: mediaServer ? mediaServer : undefined,
        logOutputLevel: 3
    })

    // 连接 IM
    return connectIM(token)
}

export const joinRTCRoom = roomId => rtcClient.joinRTCRoom(roomId)

export const leaveRTCRoom = room => rtcClient.leaveRoom(room)